<?php

/*
class cGetPost is used to handled forms values (e.g. title)
class cTableCell is used to define table cell properties (header name, cell class, cell style,...)

class cHtml is used to build html basic tags <head> and <body>
->Head()     Returns the <head></head> block including the properties
->Body($arr) Returns the <body> including the $arr attributes: supported key-values are id,class,style,title,onload,onunload
->End()      Returns the </body></html>
->Redirect   Perform html redirection
->MsgBox     Show
*/

class cGetPost
{

public $s = ''; // source string (from the form)
public $t = ''; // trimmed and stripslashed string
public $e = ''; // encoded string (convert <>"' but not &)
public function __construct($str,$size=0,$encode='Q A L R')
{
  $this->s = $str;
  $this->t = trim((get_magic_quotes_gpc() ? stripslashes($str) : $str));
  $this->e = QTencode($this->t,$encode);
  if ( $size>0 ) $this->e = substr($this->e,0,$size);
}

}

// -----------------------------

class cTableCell
{

public $id = '';     // Field key. Can be "emails_i" meaning "emails icon"
public $uid = '';    // Usable field (i.e "emails" instead of "emails_i"). By default $uid=$id (without "_i")
public $sort = false;// Default sort order (ASC,DESC,FALSE). This is used in column headers
public $name = '';   // Field (or translation)
public $class_th = '';
public $style_th = '';
public $class_td = '';
public $style_td = '';
public $class_dynamic = false; // To use this, define an array('formula-%s','field',array-of-classes). Note: keys of the array-of-classes must be strings
public $style_dynamic = false; // To use this, define an array('formula-%s','field',array-of-styles). Note: keys of the array-of-styles must be strings

function __construct($id,$name,$class_th='',$style_th='',$class_td='',$style_td='',$sort=false)
{
  $this->id = $id;
  $this->uid = ( substr($id,-2,2)=='_i' ? substr($id,0,-2) : $id );
  $this->name = $name;
  $this->class_th = $class_th;
  $this->style_th = $style_th;
  $this->class_td = $class_td;
  $this->style_td = $style_td;
  $this->sort = $sort;
}

function AddStyleDynamic($arr)
{
  // Change $this->style_td to add a dynamic style based on the parameters in $this->style_dynamic and according to the values in $arr
  if ( !is_array($arr) ) return; // row not defined
  if ( count($arr)==0 ) return; // row not defined
  if ( !is_array($this->style_dynamic) ) return; // formula not defined
  if ( count($this->style_dynamic)!=3 ) return; // formula not defined
  if ( !is_string($this->style_dynamic[0]) ) return; // formula not defined
  if ( !is_string($this->style_dynamic[1]) ) return; // formula not defined
  if ( !is_array($this->style_dynamic[2]) ) return; // styles not defined
  $key      = $this->style_dynamic[1];
  $arrStyle = $this->style_dynamic[2]; 
  $strStyle = '';
  if ( isset($arr[$key]) ) {
  if ( isset($arrStyle[strval($arr[$key])]) ) {
    $strStyle = (empty($this->style_td) ? '' : ';').sprintf( $this->style_dynamic[0], $arrStyle[strval($arr[$key])] );
  }}
  return $strStyle;
}

function AddClassDynamic($arr)
{
  // Change $this->style_td to add a dynamic style based on the parameters in $this->style_dynamic and according to the values in $arr
  if ( !is_array($arr) ) return; // row not defined
  if ( count($arr)==0 ) return; // row not defined
  if ( !is_array($this->class_dynamic) ) return; // formula not defined
  if ( count($this->class_dynamic)!=3 ) return; // formula not defined
  if ( !is_string($this->class_dynamic[0]) ) return; // formula not defined
  if ( !is_string($this->class_dynamic[1]) ) return; // formula not defined
  if ( !is_array($this->class_dynamic[2]) ) return; // styles not defined
  $key      = $this->class_dynamic[1];
  $arrClass = $this->class_dynamic[2]; 
  $strClass = '';
  if ( isset($arr[$key]) ) {
  if ( isset($arrClass[strval($arr[$key])]) ) {
    $strClass = ' '.sprintf( $this->class_dynamic[0], $arrClass[strval($arr[$key])] );
  }}
  return $strClass;
}

}

// -----------------------------

class cHtml
{

public $title = '';
public $description = '';
public $keywords = '';
public $links = array();
public $scripts = array();
public $language = 'en';
public $contenttype = 'text/html; charset=iso-8859-1';
public $dtd = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">';
public $html = '<html>'; // can be use to include xml attributes (see constructor)

// ------

function Head()
{

return $this->dtd."\r\n".$this->html.'
<head>
<title>'.$this->title.'</title>
<meta http-equiv="content-type" content="'.$this->contenttype.'" />
<meta name="description" content="'.$this->description.'" />
<meta name="keywords" content="'.$this->keywords.'" />
<meta name="author" content="qt-cute.org" />
<meta name="language" content="'.$this->language.'" />
'.implode(PHP_EOL,$this->links).PHP_EOL.implode(PHP_EOL,$this->scripts).'
</head>
';

}

// ------

function Body($arr=array())
{

return '<body'.(isset($arr['id']) ? ' id="'.$arr['id'].'"' : '').(isset($arr['class']) ? ' class="'.$arr['class'].'"' : '').(isset($arr['style']) ? ' style="'.$arr['style'].'"' : '').(isset($arr['title']) ? ' title="'.$arr['title'].'"' : '').(isset($arr['onload']) ? ' onload="'.$arr['onload'].'"' : '').(isset($arr['onunload']) ? ' onunload="'.$arr['onunload'].'"' : '').">\r\n";

}

// ------

function End()
{

return '
</body>
</html>';

}

// ------

function Redirect($u='index.php',$s='Continue')
{

if ( headers_sent() )
{
echo '<a href="'.$u.'">',$s,'</a><meta http-equiv="REFRESH" content="0;url='.$u.'">';
}
else
{
header('Location: '.str_replace('&amp;','&',$u));
}
exit;

}

// --------

function CloseWindow()
{

echo '<p><a href="#" onclick="window.close();">'.$L['Close'].' [x]</a></p>
<script type="text/javascript">window.close();</script>
';

exit;

}

// --------

function Msgbox($strTitle='',$arrBox=array(),$arrBoxTitle=array(),$arrBoxBody=array())
{

if ( empty($strTitle) && empty($arrBox) && empty($arrBoxTitle) && empty($arrBoxBody) )
{
echo '</div>
</div>
';
}
else
{
if ( !isset($arrBox['class']) )      $arrBox['class']='msgbox';
if ( !isset($arrBox['style']) )      $arrBox['style']='width:400px';
if ( !isset($arrBoxTitle['class']) ) $arrBoxTitle['class']='msgboxtitle';
if ( !isset($arrBoxBody['class']) )  $arrBoxBody['class']='msgboxbody';
echo '<div'.(isset($arrBox['id']) ? ' id="'.$arrBox['id'].'"' : '').(isset($arrBox['class']) ? ' class="'.$arrBox['class'].'"' : '').(isset($arrBox['style']) ? ' style="'.$arrBox['style'].'"' : '').(isset($arrBox['title']) ? ' title="'.$arrBox['title'].'"' : '').">\r\n";
echo '<div'.(isset($arrBoxTitle['id']) ? ' id="'.$arrBoxTitle['id'].'"' : '').(isset($arrBoxTitle['class']) ? ' class="'.$arrBoxTitle['class'].'"' : '').(isset($arrBoxTitle['style']) ? ' style="'.$arrBoxTitle['style'].'"' : '').(isset($arrBoxTitle['title']) ? ' title="'.$arrBoxTitle['title'].'"' : '').'>'.$strTitle."</div>\r\n";
echo '<div'.(isset($arrBoxBody['id']) ? ' id="'.$arrBoxBody['id'].'"' : '').(isset($arrBoxBody['class']) ? ' class="'.$arrBoxBody['class'].'"' : '').(isset($arrBoxBody['style']) ? ' style="'.$arrBoxBody['style'].'"' : '').(isset($arrBoxBody['title']) ? ' title="'.$arrBoxBody['title'].'"' : '').'>';
}

}

// ------

}